%define PYTHON_VERSION `python -c 'import sys; print "%d.%d" % sys.version_info[:2]'`

Summary: GDAL - a translator library for raster geospatial data formats
Name: gdal
Version: 1.2.3
Release: 0.fdr.2
Epoch: 0
URL: http://gdal.maptools.org/
Source: gdal-%{version}.tar.gz
Patch0: gdal-install.patch
License: MIT licence; Copyright by Frank Warmerdam
Group: System Environment/Libraries

BuildRequires: proj-devel, postgresql-devel, python, libjpeg-devel, xerces-j-devel, shapelib-devel, libungif-devel, zlib-devel, libpng-devel
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

%package devel
Summary:	Development files for gdal and ogr
Group:		Development/Libraries
Requires:	%{name} = %{epoch}:%{version}-%{release}

%package bin
Summary:	Utility programs for gdal and ogr
Group:		Applications/Productivity
Requires:	%{name} = %{epoch}:%{version}-%{release}

%package python
Summary:	Python bindings for gdal and ogr
Group:		System Environment/Libraries
Requires:	%{name} = %{epoch}:%{version}-%{release}

%description
GDAL is a translator library for raster geospatial data formats. As a library,
it presents a single abstract data model to the calling application for all
supported formats. The related OGR library (which lives within the GDAL source
tree) provides a similar capability for simple features vector data.

GDAL supports 40+ popular data formats, including commonly used ones (GeoTIFF,
JPEG, PNG and more) as well as the ones used in GIS and remote sensing software
packages (ERDAS Imagine, ESRI Arc/Info, ENVI, PCI Geomatics). Also supported
many remote sensing and scientific data distribution formats such as HDF, EOS
FAST, NOAA L1B, NetCDF, FITS.

OGR library supports popular vector formats like ESRI Shapefile, TIGER data,
S57, MapInfo File, DGN, GML and more.

%description devel
This package contains libgdal and the appropriate header files.

%description bin
This package contains utility programs, based on GDAL/OGR library, namely
gdal_translate, gdalinfo, gdaladdo, gdalwarp, ogr2ogr, ogrinfo, ogrtindex. 

%description python
This package contains Python bindings for GDAL/OGR library. 

%prep
%setup gdal-%{version}
#./configure --prefix=%{_prefix} --mandir=%{_mandir}
%configure 

cp GDALmake.opt GDALmake.opt.orig
sed -e "s/^CFLAGS.*$/CFLAGS=$CFLAGS/" GDALmake.opt.orig | 
sed -e "s/^CXXFLAGS.*$/CXXFLAGS=$CXXFLAGS/" |
sed -e "s/^FFLAGS.*$/FFLAGS=$FFLAGS/" > GDALmake.opt

%patch0 -p0

%build
make  %{?_smp_mflags}

%install
rm -rf %{buildroot}
%makeinstall INST_PYMOD=%{buildroot}/usr/lib/python%{PYTHON_VERSION}/site-packages INST_MAN=%{buildroot}/%{_mandir} INST_LIB=%{buildroot}/%{_libdir} INST_INCLUDE=%{buildroot}/%{_includedir} INST_BIN=%{buildroot}/%{_bindir} INST_DATA=%{buildroot}/%{_datadir}


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%clean
rm -rf %{_builddir}/%{name}-%{version}
rm -rf %{buildroot}

%files 
%defattr(-,root,root)
%{_libdir}/lib*.so*
%{_datadir}/*
%exclude %{_mandir}
%doc html ChangeLog VERSION NEWS HOWTO-RELEASE

%files devel
%defattr(-,root,root,-)
%{_bindir}/gdal-config
%{_includedir}/*
%{_libdir}/*.a
%exclude %{_libdir}/libgdal.la
%exclude %{_libdir}/libgdal.so*

%files bin
%defattr(-,root,root,-)
%{_bindir}/*
%{_mandir}/man1/*
%exclude %{_bindir}/gdal-config

%files python
%defattr(-,root,root,-)
%{_libdir}/python*/site-packages/*
%exclude %{_libdir}/python*/site-packages/*.a

%changelog
* Wed Sep 29 2004 Silke Reimer <silke.reimer@intevation.net> 0:1.2.3-0.fdr.2
- new upstream version

* Mon Sep 27 2004 Silke Reimer <silke.reimer@intevation.net> 0:1.2.2-0.fdr.2
- new upstream version
- make use of $RPM_OPT_FLAGS by patching GDALmake.opt
- explicit set of _prefix has been dropped

* Tue Aug 31 2004 Silke Reimer <silke.reimer@intevation.net> 0:1.2.1-1.fdr.2
- Changed BuildRoot according to standard specfile.
- Added %{?_smp_mflags} to make
- Changed post and postun to avoid printing and additional requirements for 
  post and postun
- Changed Group of main package to "System Environment/Libraries"
- Use %configure-macro 

* Fri Aug 06 2004 Silke Reimer <silke.reimer@intevation.net> - 0:1.2.1-0.fdr.2
- substantial changes to fit to Fedora naming conventions

* Wed Jun 30 2004 Silke Reimer <silke.reimer@intevation.net> - 1.2.1-0
- Initial build
